@@ -33,7 +33,7 @@ dist = pkg_resources.get_distribution('nginx-sites')
 config = {
 	'sites_enabled': '/etc/nginx/sites-enabled/',
 	'sites_available': '/etc/nginx/sites-available/',
-	'templates_path': os.path.join(dist.location, 'templates')
+	'templates_path': os.path.join(dist.location, 'nginxSites', 'templates')
 }
 
 
@@ -97,7 +97,7 @@ class NginxSites:
 
 
 def main():
-	args = docopt(__doc__, version='nginx-sites 0.0.2')
+	args = docopt(__doc__, version='nginx-sites 0.0.3')
 	nginxSites = NginxSites(config)
 	if args['ls']:
 		nginxSites.ls()
